@@ -18,9 +18,8 @@ from PySide.QtGui import *
 import sys
 import foursquare
 from foursquare import Cache
-from gui import WaitingDialog
 from locationProviders import LocationProvider
-from custom_widgets import SignalEmittingValueButton
+from custom_widgets import SignalEmittingValueButton, WaitingDialog
 from threads import TipMarkTodoBackgroundThread, TipMarkDoneBackgroundThread
 import time
 
